@@ -1,5 +1,8 @@
 from packaging_tutorial.lanedetection.model import test1
 
+
 def cc(x,y):
     a = test1.bb(x,y)
-    print(a)
\ No newline at end of file
+    return a
+
+
